AddressOwner class
Represents an object owned by an address.
- Inheritance
-
- Object
- ObjectOwner
- AddressOwner
- Annotations
Constructors
- AddressOwner(SuiAddress address)
-
const
-
AddressOwner.fromJson(Map<
String, dynamic> json) -
factory
Properties
- address → SuiAddress
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON representation.
override
-
toString(
) → String - A string representation of this object.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited