FieldMask class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
-
checkpointBasic
→ const List<
String> -
checkpointFull
→ const List<
String> -
checkpointTransactions
→ const List<
String> -
objectBasic
→ const List<
String> -
objectContent
→ const List<
String> -
objectFull
→ const List<
String> -
transactionBasic
→ const List<
String> -
transactionEffects
→ const List<
String> -
transactionEvents
→ const List<
String> -
transactionFull
→ const List<
String>