SuiNetworkConfig class

Constructors

SuiNetworkConfig({required String endpoint, required int port, required bool useSSL, Duration timeout = const Duration(seconds: 30), Map<String, String> metadata = const {}, SuiNetwork? network})
const
SuiNetworkConfig.custom({required String endpoint, int port = 443, bool useSSL = true, Duration? timeout, Map<String, String>? metadata})
Factory: Create configuration for a custom Sui network
factory
SuiNetworkConfig.forNetwork(SuiNetwork network, {Duration? timeout, Map<String, String>? metadata})
Factory: Create configuration for a specific Sui network
factory

Properties

endpoint String
final
grpcUrl String
Get the complete gRPC URL
no setter
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, String>
final
network SuiNetwork?
final
port int
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setter
timeout Duration
final
useSSL bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited